Skip to contents

Determine if the session is suitable for executing long-running examples.

Usage

run_example()

Value

A logical value.

Details

This function will return TRUE if the session is interactive. Otherwise, it will only return TRUE if the session does not have system environmental variables that indicate that the session is being used for package checks, or for building documentation.

Examples

# should examples be run in current environment?
run_example()
#> [1] TRUE